package net.sf.sidaof.dao.jpa;

import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;

/**
 * Convenience base class for JPA DAOs using the default (no unitName specified)
 * entity manager. To use, extend it in DAO classes.
 * 
 * @param <K>
 *            The primary key class of the entity, e.g. Long.
 * @param <E>
 *            The entity class the DAO persists, e.g. Person.
 */
public class JpaDaoImpl<K, E> extends AbstractJpaDao<K, E> implements
        JpaDao<K, E> {
    @PersistenceContext
    protected EntityManager entityManager;

    /** Make a new instance, automatically determining the entity class. */
    public JpaDaoImpl() {
        super();
    }

    /**
     * Make a new instance, specifying the entity class.
     * 
     * @param entityClass
     *            The entity class to manage.
     */
    public JpaDaoImpl(Class<E> entityClass) {
        super(entityClass);
    }

    @Override
    public EntityManager getEntityManager() {
        return entityManager;
    }

    @Override
    public void setEntityManager(EntityManager entityManager) {
        this.entityManager = entityManager;
    }
}
