package net.sf.sidaof.service;

import java.util.Collection;
import java.util.List;

import net.sf.sidaof.dao.Dao;

/**
 * Base class for services providing complete DAO functionality.
 * 
 * @author Jeff Jensen
 */
public abstract class AbstractDaoService<K, E> {
    public abstract Dao<K, E> getDao();

    public void clear() {
        getDao().clear();
    }

    public boolean contains(E entity) {
        return getDao().contains(entity);
    }

    public Long countAll() {
        return getDao().countAll();
    }

    public Long countAll(String where, String pathExpression) {
        return getDao().countAll(where, pathExpression);
    }

    public Long countAll(String where) {
        return getDao().countAll(where);
    }

    public List<E> findAll() {
        return getDao().findAll();
    }

    public List<E> findAll(int startPosition, int maxResult) {
        return getDao().findAll(startPosition, maxResult);
    }

    public E findById(K id) {
        return getDao().findById(id);
    }

    public void flush() {
        getDao().flush();
    }

    public E merge(E entity) {
        return getDao().merge(entity);
    }

    public void persist(Collection<E> entities) {
        getDao().persist(entities);
    }

    public void persist(E entity) {
        getDao().persist(entity);
    }

    public void refresh(E entity) {
        getDao().refresh(entity);
    }

    public void remove(E entity) {
        getDao().remove(entity);
    }
}
