package net.sf.sidaof.service.hibernate;

import net.sf.sidaof.dao.hibernate.HibernateDao;
import net.sf.sidaof.service.AbstractDaoService;

import org.hibernate.LockMode;
import org.hibernate.Query;
import org.hibernate.Session;
import org.hibernate.SessionFactory;

/**
 * Base class for services providing complete Hibernate DAO functionality.
 * 
 * @author Jeff Jensen
 */
public abstract class AbstractHibernateDaoService<K, E> extends
        AbstractDaoService<K, E> {
    @Override
    public abstract HibernateDao<K, E> getDao();

    public E findById(K id, LockMode lockMode, boolean exceptionIfNotFound) {
        return getDao().findById(id, lockMode, exceptionIfNotFound);
    }

    // FIXME this in AbstractDao, not in HibernateDao or Dao interfaces but rest
    // are; need it?
    // public Class<E> getEntityClass() {
    // return getDao().getEntityClass();
    // }

    public Session getSession() {
        return getDao().getSession();
    }

    public SessionFactory getSessionFactory() {
        return getDao().getSessionFactory();
    }

    public E runQueryWithSingleResult(Query q, LockMode lockMode,
            boolean exceptionIfNotFound) {
        return getDao().runQueryWithSingleResult(q, lockMode,
                exceptionIfNotFound);
    }

    public E runQueryWithSingleResult(Query q) {
        return getDao().runQueryWithSingleResult(q);
    }

    public void setSessionFactory(SessionFactory sessionFactory) {
        getDao().setSessionFactory(sessionFactory);
    }
}
